#
# spec file for package gbrainy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gbrainy
Version:        2.3.5
Release:        bp153.1.99
Summary:        A brain teaser game and trainer
License:        GPL-2.0-or-later
Group:          Amusements/Games/Logic
URL:            https://wiki.gnome.org/Apps/gbrainy
Source:         https://gent.softcatala.org/jmas/gbrainy/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE -- gbrainy-use-libexecdir.patch
Patch0:         gbrainy-use-libexecdir.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gtk-sharp-3.0) >= 2.99.1
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.26
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(mono) >= 4.0.0
BuildRequires:  pkgconfig(mono-addins) >= 0.2.0
Recommends:     %{name}-lang
# For the help system to work, we require a ghelp:// URI handler.
Recommends:     mimehandler(x-scheme-handler/ghelp)
BuildArch:      noarch
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif

%description
gbrainy is a brain teaser game and trainer to have fun and to keep
your brain trained.

It provides the following types of games:

* Logic puzzles. Games designed to challenge your reasoning and
  thinking skills.

* Mental calculation. Games based on arithmetical operations
  designed to prove your mental calculation skills.

* Memory trainers. Games designed to challenge your short term
  memory.

* Verbal analogies. Games that challenge your verbal aptitude.

%prep
%setup -q
%if !0%{?is_opensuse}
translation-update-upstream
%endif
%patch0

%lang_package

%build
export MONO_SHARED_DIR=%{_localstatedir}/tmp
%configure \
        --disable-static
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}
rm -rf %{buildroot}%{_datadir}/pixmaps
# There are no extensions yet, Thus creating a -devel package sounds overkill (file can't reside in noarch package).
rm %{buildroot}%{_libdir}/pkgconfig/gbrainy.pc

# When below tests fail, we can now remove the chmod
test -x %{buildroot}%{_libexecdir}/%{name}/gbrainy.exe.config
chmod -x %{buildroot}%{_libexecdir}/%{name}/gbrainy.exe.config

%files
%license COPYING
%doc AUTHORS NEWS README
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/games/%{name}/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Apr 13 2018 luc14n0@linuxmail.org
- Update to version 2.3.5:
  + 3 small bug fixes.
  + Updated translations.
* Mon Mar  5 2018 luc14n0@linuxmail.org
- Update to version 2.3.4:
  + 2 new games.
  + 4 small bug fixes.
  + Updated translations.
- Update '+' in GPL License tag to '-or-later' to comply with SPDX
  3.0.
- Drop update-desktop-files BuildRequires and its macro: they are
  no longer necessary.
* Sun Nov  5 2017 luc14n0@linuxmail.org
- Update to version 2.3.3:
  + 3 new games.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/gbrainy: current
  gbrainy's web page.
- Point fdupes to the data directory intead of the build root,
  which is a practice that must be avoided.
- Drop %%desktop_database_* and %%icon_theme_cache_* post(un)
  scriplets: the functionality now is covered by file triggers.
- Add conditional use to translation-update-upstream since it's a
  SLE-only requirement.
* Sat Sep  9 2017 zaitor@opensuse.org
- Update to version 2.3.2:
  + 1 bug fix (bgo#772327).
  + Updated translations.
- Run spec-cleaner, modernize spec file.
* Thu Nov  3 2016 dimstar@opensuse.org
- Update to version 2.3.1:
  + Port to new documentation infrastructure.
  + Better metadata describing the app for software centers.
  + Small bug fixes.
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires for yelp-tools,
  following upstreams port to the new documentation infrastructure.
- Drop gbrainy-appdata-workaround.patch: fixed upstream.
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to version 2.3.0:
  + Ported to Gtk3.
  + Small fixes.
  + Updated translations.
- Add gbrainy-appdata-workaround.patch: Directly link to https.
  Fixed upstream already (bgo#770604).
- Replace BuildRequirements:
  + gtk-sharp2 for pkgconfig(gtk-sharp-3.0).
  + pkgconfig(libcanberra-gtk) for pkgconfig(libcanberra-gtk3).
  + librsvg-devel for pkgconfig(librsvg-2.0).
  + mono-addins for pkgconfig(mono-addins).
  + mono-devel for pkgconfig(mono).
* Tue Jan 12 2016 dimstar@opensuse.org
- Update to version 2.2.7:
  + Fixed 2 bugs.
  + Standardize on .Net 4.5 and msc compiler.
  + Updated translations.
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 2.2.6:
  + Updated translations.
- Clean-up specfile.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 2.2.5:
  + Updated translations.
* Thu Jan  1 2015 zaitor@opensuse.org
- Update to version 2.3.4:
  + 2 bug fixes.
  + Mono 3.0 or higher required.
  + Updated translations.
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 2.2.3:
  + 2 bug fixes.
  + Updated translations.
* Mon Sep 16 2013 zaitor@opensuse.org
- Update to version 2.2.2:
  + 1 bug fix (bgo#704354).
  + Updated translations.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 2.2.1:
  + Mono 3.0 compatibility.
  + 2 bug fixes.
  + Updated translations.
- Drop gbrainy-2.1.5-CSharpCompiler.patch, fixed upstream.
* Wed Apr 17 2013 dimstar@opensuse.org
- Update to version 2.2.0:
  + New games: 3 new logic games, 2 calculation games and 17 new
    verbal analogies.
  + Improved the graphics of 10 puzzles.
  + More mouse support in some old puzzles.
  + Sound support.
  + 3 bug fixes.
- Add pkgconfig(libcanberra-gtk) BuildRequires: dependency for the
  new sound support.
* Tue Jan  8 2013 gankov@opensuse.org
- Update to version 2.1.5:
  + Remove code to handle low resolutions, let the system to decide
  + Some new verbal analogies
  + Updated translations.
- Changes from 2.1.4:
  + Bugs fixed: bgo#676211·
  + Updated translations.
- Changes from 2.1.3:
  + In memory count dots puzzle, we were not painting all dots in
    some cases plus we were always asking for the red dot color in
    the question instead of random
  + Updated translations.
- Changes from 2.1.2:
  + Allow to set the time to memorize a question below 4 for very
    advanced players
  + Text should be plural in the sentence
  + Bugs fixed: bgo#655725, bgo#669105, bgo#669102, bgo#669099,
    bgo#669106, bgo#669104.
  + Updated translations.
- Changes from 2.1.1:
  + The correct answer for the Average game was always the smaller
    option
  + Updated translations.
- Changes from 2.1.0:
  + Software improvements
  - Refactoring to break down responsibilities in classes and
    make code more modular
  - Automated “Assembly / package versioning”
  + Existing games improvements
  - Mouse support for Memorize figures and text
  - Show graphically the answer in square sheets puzzle
  - Add rationale to handshake puzzle
  - People at the table has a better graphic
  - Some controls in games handle better larger texts
  + Updated translations.
- Add patch gbrainy-2.1.5-CSharpCompiler.patch - fix build for
  mono-3.0
- Use spec-cleaner
- Use fdupes
- Fix executable permission on gbrainy.exe.config
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 dimstar@opensuse.org
- Update to version 2.06:
  + Bugs fixed: bgo#663259
  + Updated translations,
- Changes from version 2.05:
  + Fixes Family relation English version of the Puzzle.
- Changes from version 2.04:
  + Bugx fixed: bgo#661307, bgo#662041, bgo#881156
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 2.03:
  + Fixes assembly versioning
  + Updated translations.
* Tue Sep 13 2011 vuntz@opensuse.org
- Update to version 2.02:
  + 7 bugs fixed
  + Updated translations.
* Sat Aug  6 2011 dimstar@opensuse.org
- Update to version 2.01:
  + Add Mono.Addins.Gui 0.6 strings for L10N
  + remove libgnome support (deprecated lib)
  + 11 bugs fixed
- Remove --disable-gnome configure parameter, as the support has
  been removed upstream.
* Fri Jul  8 2011 vuntz@opensuse.org
- Do not build with useless GNOME support (which adds a dependency
  on gnome-sharp2, for no big reason), see bgo#654225:
  + Remove gnome-sharp2 BuildRequires.
  + Pass --disable-gnome to configure.
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 2.00:
  + UI:
  - Integrated question and solution
  - Theme support
  - New default theme (notebook)
  - Vertical / Horizontal toolbar orientation
  + Game experience:
  - Better answer handling
  - Accept words, accept figures names, more flexibility handling
    spaces, etc
  - Better rationale explanations (%%)
  - Fixed some verbal analogies
  + Localization:
  - I18N fixes
  - Proof-reading on English by native speakers. 20%% of strings
    where enhanced for better grammar.
  - Ability to run gbrainy in English ignoring the translations
  + 11 new games: 4 logic games, 1 calculation game, 6 new verbal
    analogies
  + Infrastructure Fixes
  - Minor memory leaks
  - Mono 2.10 support
  + Several bug fixes
- Remove unneeded glade-sharp2 BuildRequires.
- Remove filesystem PreReq, which doesn't need to be explicit.
- Rebase gbrainy-use-libexecdir.patch.
* Wed Apr 27 2011 dimstar@opensuse.org
- Update to version 1.65:
  + 2 bug fixes
- Changes from version 1.64:
  + Small bug fixes
  + Updated translations.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 1.63:
  + 2 bug fixes
  + More flexiblity accepting answers
  + Updated and new translations.
* Sun Feb 27 2011 bjorn.lie@gmail.com
- Update to version 1.62:
  + 4 bug fixes.
  + Updated translations.
- Drop gbrainy-fix-build.patch: fixed upstream.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Thu Feb 10 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Use %%{?no_lang_C} instead of %%no_lang_C to fix build on 11.3 and
  earlier.
* Wed Jan 26 2011 dimstar@opensuse.org
- Split out -lang package which is Recommended by the main package.
  Keep the C lang help in the main package
- Recommend mimehandler(x-scheme-handler/ghelp) for the help
  system to work.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 1.61:
  + 5 bug fixes
  + Updated translations.
- Add gbrainy-fix-build.patch to fix build with mono 2.8.
* Mon Dec 13 2010 vuntz@opensuse.org
- Update to version 1.60:
  + Better I18N (string concatenation and plurals)
  + 7 new logic games, 1 calculation and 16 verbal analogies
  + PDF export support
  + 14 bug fixes
  + Updated translations.
* Sun Sep 26 2010 vuntz@opensuse.org
- Update to version 1.52:
  + 3 bug fixes
  + Updated translations.
* Fri Sep  3 2010 vuntz@opensuse.org
- Update to version 1.51:
  + 5 bug fixes
  + Updated translations.
* Tue Aug  3 2010 dimstar@opensuse.org
- Update to version 1.50:
  + 11 new logic games, 4 new calculation trainers, 13 verbal
    analogies
  + Usability enhancements
  + Unit testing for the gbrainy.Core
  + Ability to define external logic puzzles using an xml file
    (games.xml)
  + Command line support
  + 7 bug fixes
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 1.42:
  + 14 bugs fixed
  + Updated translations.
* Sun May  2 2010 dimstar@opensuse.org
- bnc#601771: Fix gbrainy-use-libexecdir-patch: the game is
  installed in libexecidir/packagename. The shell wrapper missed
  this.
* Fri Apr  2 2010 vuntz@opensuse.org
- Update to version 1.41:
  + 18 bug fixes
  + Updated translations.
* Mon Mar  1 2010 dimstar@opensuse.org
- Update to version 1.40:
  + 2 new logic games
  + Deprecated Glade and moved to Builder
  + Mouse support
  + Better RTL support
  + Updated and new translations
  + Remove dead and legacy code
  + 12 Bug fixes
- Rebase gbrainy-use-libexecdir.patch.
* Fri Jan  8 2010 vuntz@opensuse.org
- Update to version 1.30:
  + Re-architectured for better multiplatform support
  + Personal records tracking
  + Improved player scoring algorithm
  + Better accessibility
  + 9 new verbal analogies and a new logic puzzle
  + Mallard documentation
  + More HIG compliance
  + Bug fixes
- Add gnome-doc-utils-devel BuildRequires.
- Rename libdir.patch to gbrainy-use-libexecdir.patch, and rebase
  it. Also add Makefile.in changes there so that we don't need to
  call autoreconf.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 1.20:
  + 6 new games
  + Verbal analogies
  + New translations
  + Bug fixes
* Tue Dec  1 2009 crrodriguez@opensuse.org
- fix libdir.patch to apply with fuzz=0
- pass --disable-static to configure
* Sat Aug 22 2009 dimstar@opensuse.org
- Update to version 1.12:
  + Bug fixes
  + Updated translations.
* Sun Jun 14 2009 vuntz@novell.com
- Update to version 1.11:
  + 4 new games
  + Use Mono.Addins for extending gbrainy
  + Full screen mode support
  + New translations
  + Bug fixes
- Remove perl-XML-Parser BuildRequires: it's not needed.
- Add mono-addins BuildRequires.
- Remove AutoReqProv: it's default now.
- Do not set CFLAGS to the default value.
- Use makeinstall macro.
* Mon Dec 29 2008 mboman@suse.de
- Update to version 1.01:
  + Minor fix to configure
* Tue Sep  2 2008 ajorgensen@novell.com
- Update to version 1.00
  * 1 new logic puzzle, 1 new memory puzzle
  * Better look and feel (new background)
  * Switch font drawing to Pango
  * Better I18N support
  * Bug fixes
* Thu Aug  7 2008 mauro@suse.de
- Update to version 0.7
  * 8 new puzzles
  * License included in the about box
  * The drawing area is now square and the application resizes better
  * Better score feedback
  * Player's history
  * Preferences persistence
  * Better game selection
  * Bug fixes
* Mon Mar 31 2008 vuntz@suse.de
- Update to version 0.61:
  + Implemented difficulty levels: easy, medium and master
  + Complete revision of the texts
  + 1 new math game and 3 new logic games
  + Bug fixes
- Changes from version 0.5x:
  + Basic user preferences (memory games)
  + 4 new logic games and 2 new memory trainers
  + Count down for memory games (to get your memory ready)
  + Some bug fixes
* Wed Feb 13 2008 ajorgensen@novell.com
- Initial import
